.. _user-guide:

##########
User Guide
##########

Welcome to the **alchemiscale** **User Guide**!
If you are making use of an **alchemiscale** instance, this document will familiarize you with how to make effective use of it for scaling out your alchemical free energy calculations.

.. toctree::
   :maxdepth: 1

   ./getting_started
   ./handling_errors
   ./strategy_automation
